pub struct Responses(/* private fields */);Expand description
The model may return more than one output since we use streaming. This wrapper is used as a helper to consolidate the outputs.
Implementations