pub enum GoogleModelVariant {
Gemini20FlashExpImageGen,
Gemini20Flash,
Gemini25Flash,
Gemini25Pro,
Gemini25FlashLight,
}Expand description
Supported Google AI models. Some models have different capabilities than others, so this enum may be used to branch the different capabilities.
Variants